Crate text2binary

Crate text2binary 

Functions

convert
Converts a string representation of a hexadecimal number to a Vec<u8>.
convert_file
Convert a text file containing a hexadecimal string representation to a Vec<u8>.
convert_line
Converts a vector of hexadecimal string representation to a Vec<u8>.