Functions
- convert
- Converts a string representation of a hexadecimal number to a Vec<u8>.
- convert_
file - Convert a text file containing a hexadecimal string representation to a Vec<u8>.
- convert_
line - Converts a vector of hexadecimal string representation to a Vec<u8>.